module ExpressPigeon
  # AutoResponders
  class AutoResponders
    include HTTParty
    base_uri('https://api.expresspigeon.com/auto_responders')

    # Get all autoresponders
    #
    # GET https://api.expresspigeon.com/auto_responders
    def index
      self.class.get('')
    end

    # Start for a contact
    #
    # POST https://api.expresspigeon.com/auto_responders/{auto_responder_id}/start
    def start(auto_responder_id, email_address)
      options = {}
      options['email'] = email_address

      self.class.post(
        "/#{auto_responder_id}/start",
        body: options.to_json,
        headers: { 'Content-Type' => 'application/json' }
      )
    end

    # Stop for a contact
    #
    # POST https://api.expresspigeon.com/auto_responders/{auto_responder_id}/stop
    def stop(auto_responder_id, email_address)
      options = {}
      options['email'] = email_address

      self.class.post(
        "/#{auto_responder_id}/stop",
        body: options.to_json,
        headers: { 'Content-Type' => 'application/json' }
      )
    end

    # Report for a single autoresponder
    #
    # GET https://api.expresspigeon.com/auto_responders/{auto_responder_id}
    def report(auto_responder_id)
      self.class.get("/#{auto_responder_id}")
    end

    # Get bounced contacts for autoresponder part
    #
    # GET https://api.expresspigeon.com/auto_responders/{auto_responder_id} /{auto_responder_part_id}/bounced
    def report_bounced(auto_responder_id, auto_responder_part_id)
      self.class.get("/#{auto_responder_id}/#{auto_responder_part_id}/bounced")
    end

    # Get unsubscribed contacts for autoresponder part
    #
    # GET https://api.expresspigeon.com/auto_responders/{auto_responder_id} /{auto_responder_part_id}/unsubscribed
    def report_unsubscribed(auto_responder_id, auto_responder_part_id)
      self.class.get("/#{auto_responder_id}/#{auto_responder_part_id}/unsubscribed")
    end

    # Get spam contacts for autoresponder part
    #
    # GET https://api.expresspigeon.com/auto_responders/{auto_responder_id} /{auto_responder_part_id}/spam
    def report_spam(auto_responder_id, auto_responder_part_id)
      self.class.get("/#{auto_responder_id}/#{auto_responder_part_id}/spam")
    end
  end
end
