module ExpressPigeon
  # Contacts
  #
  # Contacts end point allows you to create, read, update and delete contacts
  # on your lists. A contact consists of required email and various standard
  # and custom fields.
  class Contacts
    include HTTParty

    base_uri('https://api.expresspigeon.com/contacts')
    debug_output(nil)

    def initialize(auth_key)
      self.class.headers('X-auth-key' => auth_key)
    end

    # Read a single contact by email
    #
    # GET https://api.expresspigeon.com/contacts
    def find(email_address)
      self.class.get('/', query: { email: email_address })
    end

    # Create or update contacts
    #
    # POST https://api.expresspigeon.com/contacts
    def create(list_id, contacts)
      fail "Contacts must be an Array received #{contacts.class.name}." unless contacts.is_a?(Array)

      options = {
        'list_id' => list_id,
        'contacts' => contacts
      }

      self.class.post(
        '/',
        body: options.to_json,
        headers: { 'Content-Type' => 'application/json' }
      )
    end
    alias_method :update, :create

    # Delete a single contact
    #
    # DELETE https://api.expresspigeon.com/contacts
    #
    # email:   contact email to be deleted
    # list_id: list id to remove contact from, if not provided contact will
    #          be deleted from system.
    def delete(email_address, list_id: nil)
      options = {}
      options['email'] = email_address
      options['list_id'] = list_id unless list_id.nil?

      self.class.delete(
        '',
        body: options.to_json,
        headers: { 'Content-Type' => 'application/json' }
      )
    end

    # Move contacts between lists
    #
    # POST https://api.expresspigeon.com/contacts/move
    def move(source_list_id, target_list_id, email_addresses)
      fail "Email address must be an Array received #{email_addresses.class.name}." unless email_addresses.is_a?(Array)

      options = {}
      options['source_list'] = source_list_id
      options['target_list'] = target_list_id
      options['contacts'] =  email_addresses

      self.class.post(
        '/move',
        body: options.to_json,
        headers: { 'Content-Type' => 'application/json' }
      )
    end
  end
end
